% CREDITS: Jacqueline Meyer, Giovanni Apruzzese

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{unili}[2021/12/20 Class for UniLi's documents (v1)]

\documentclass[twoside, 11pt]{article}

\usepackage[utf8]{inputenc}
\usepackage{mathptmx}
\usepackage{xcolor}
\usepackage{eso-pic}
\usepackage{soul}

\usepackage[immediate]{silence}

\usepackage[T1]{fontenc}
\usepackage[english]{babel}
\usepackage[titles]{tocloft}
\usepackage{enumitem}
\WarningFilter[temp]{latex}{Command} % silence the warning
\usepackage{sectsty}
\DeactivateWarningFilters[temp] % So nothing unrelated gets silenced

\usepackage{chngpage}
\usepackage{calc}

\usepackage[a4paper, left=2.5cm, right=2.5cm, top=2.1cm, bottom=1.5cm, headsep=5mm, includeheadfoot]{geometry}
\sectionfont{\fontsize{12}{15}\selectfont}

\usepackage[style=apa,
citestyle=authoryear
]{biblatex}

\renewcommand{\labelenumii}{\theenumii}
\renewcommand{\theenumii}{\theenumi.\arabic{enumii}}



\setlength{\parskip}{0.5em} 


\usepackage{hyperref}
\hypersetup{
  colorlinks   = true,    % Colours links instead of ugly boxes
  urlcolor     = black,    % Colour for external hyperlinks
  linkcolor    = black,    % Colour of internal links
  citecolor    = black      % Colour of citations
}


\usepackage{fancyhdr}
\pagestyle{fancy}
\headheight=14pt
\renewcommand\headrule{}
\renewcommand{\headrulewidth}{50pt}
\fancyhf{}
\rhead{\textcolor{black!50}{\footnotesize{\papertitle}}}
\fancyfoot[LE, RO]{\thepage}



\usepackage{csquotes}
\usepackage[onehalfspacing]{setspace}






\renewcommand*{\nameyeardelim}{\addcomma\space}

\renewcommand{\baselinestretch}{1.2}


\usepackage{graphicx}





%%% You can modify the numbers to regulate the spacing between dots
\renewcommand{\cftsecdotsep}{1}
\renewcommand\cftsecleader{\bfseries\large\cftdotfill{\cftsecdotsep}}
\renewcommand{\cftsubsecdotsep}{1}
\renewcommand\cftsubsecleader{\normalsize\cftdotfill{\cftsubsecdotsep}}
\renewcommand{\cftsubsubsecdotsep}{1}
\renewcommand\cftsubsubsecleader{\small\cftdotfill{\cftsubsubsecdotsep}}

\newcommand\secdotfill{\textbf{\cftdotfill{\cftsecdotsep}}}
\newcommand\subsecdotfill{\cftdotfill{\cftsubsecdotsep}}


\author{\authorname} % This is the author of the document

\renewcommand*\contentsname{Table of Contents}

\newcommand{\preliminaryTOCbox}[1]{
    \vspace{1em}
    \noindent\fbox{%
        \parbox{\columnwidth}{%
            {#1}
        }%
    }
}

\newcommand\preliminaryTOCend{
\item \textbf{Conclusion} \secdotfill tbd
    
    \item[] \hspace{-1cm} \textbf{List of References} \secdotfill tbd
    \item[] \hspace{-1cm} \textbf{List of Figures} \secdotfill tbd
    \item[] \hspace{-1cm} \textbf{List of Tables} \secdotfill tbd
    \item[] \hspace{-1cm} \textbf{List of Abbreviations} \secdotfill tbd
    \item[] \hspace{-1cm} \textbf{Annex} \secdotfill tbd
    \item[] \hspace{-1cm} \textbf{Declaration of Authorship} \secdotfill tbd
    }
    
    